==> openshift-model-operatorhub-5.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RequirementStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RequirementStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToDependents(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public A setToDependents(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public A addToDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... items);
  public A addAllToDependents(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> items);
  public A removeFromDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... items);
  public A removeAllFromDependents(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> items);
  public A removeMatchingFromDependents(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDependents instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> getDependents();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> buildDependents();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildDependent(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildFirstDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildLastDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public A withDependents(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> dependents);
  public A withDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... dependents);
  public java.lang.Boolean hasDependents();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> addNewDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> addNewDependentLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> setNewDependentLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editDependent(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editFirstDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editLastDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public java.lang.String getGroup();
  public A withGroup(java.lang.String group);
  public java.lang.Boolean hasGroup();
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getStatus();
  public A withStatus(java.lang.String status);
  public java.lang.Boolean hasStatus();
  
  /**
   * Method is deprecated. use withStatus instead.
   */
  @java.lang.Deprecated
  public A withNewStatus(java.lang.String arg0);
  public java.lang.String getUuid();
  public A withUuid(java.lang.String uuid);
  public java.lang.Boolean hasUuid();
  
  /**
   * Method is deprecated. use withUuid instead.
   */
  @java.lang.Deprecated
  public A withNewUuid(java.lang.String arg0);
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public interface DependentsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<N>>{
    public N and();
    public N endDependent();
    
  }
  
}

==> openshift-model-operatorhub-5.12.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/RequirementStatusFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RequirementStatusFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToDependents(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public A setToDependents(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public A addToDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... items);
  public A addAllToDependents(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> items);
  public A removeFromDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... items);
  public A removeAllFromDependents(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> items);
  public A removeMatchingFromDependents(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDependents instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> getDependents();
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> buildDependents();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildDependent(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildFirstDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildLastDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus buildMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public java.lang.Boolean hasMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public A withDependents(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus> dependents);
  public A withDependents(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus... dependents);
  public java.lang.Boolean hasDependents();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> addNewDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> addNewDependentLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> setNewDependentLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatus item);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editDependent(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editFirstDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editLastDependent();
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<A> editMatchingDependent(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusBuilder> predicate);
  public java.lang.String getGroup();
  public A withGroup(java.lang.String group);
  public java.lang.Boolean hasGroup();
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getStatus();
  public A withStatus(java.lang.String status);
  public java.lang.Boolean hasStatus();
  
  /**
   * Method is deprecated. use withStatus instead.
   */
  @java.lang.Deprecated
  public A withNewStatus(java.lang.String arg0);
  public java.lang.String getUuid();
  public A withUuid(java.lang.String uuid);
  public java.lang.Boolean hasUuid();
  
  /**
   * Method is deprecated. use withUuid instead.
   */
  @java.lang.Deprecated
  public A withNewUuid(java.lang.String arg0);
  public java.lang.String getVersion();
  public A withVersion(java.lang.String version);
  public java.lang.Boolean hasVersion();
  
  /**
   * Method is deprecated. use withVersion instead.
   */
  @java.lang.Deprecated
  public A withNewVersion(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface DependentsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operatorhub.v1alpha1.DependentStatusFluent<io.fabric8.openshift.api.model.operatorhub.v1alpha1.RequirementStatusFluent.DependentsNested<N>>{
    public N and();
    public N endDependent();
    
  }
  
}
